pub struct AddReport {
pub name: String,
pub outcome: AddOutcome,
pub manifest_created: bool,
pub manifest: Manifest,
}Expand description
Result of add.
Fields
name: StringThe dep name that was written.
outcome: AddOutcomeAdded vs replaced.
manifest_created: boolWhether the manifest file had to be created from scratch
(always false for ManifestSource::Value).
manifest: ManifestThe manifest after the insertion. For ManifestSource::File this
is what was written to manifest_path(); for
ManifestSource::Value it is the only place the change exists.