Project

Struct Project 

pub struct Project { /* private fields */ }
Everything an operation in crate::ops needs to locate files.

Built once by the caller and passed by reference to install / add / update / clean. Paths are used as given (relative paths resolve against the process working directory, as with any std::fs call).

Example

use mlua_pkg::{PkgDir, Project};
use std::path::Path;

// Conventional layout: <root>/mlua-pkg.toml, <root>/mlua-pkg.lock,
// <root>/.mlua-pkgs/{cache,vendored}
let p = Project::in_dir("/srv/app", PkgDir::default_in("/srv/app"));
assert_eq!(p.manifest_path(), Path::new("/srv/app/mlua-pkg.toml"));
assert_eq!(p.lock_path(), Path::new("/srv/app/mlua-pkg.lock"));
assert_eq!(p.pkg_dir().vendored(), Path::new("/srv/app/.mlua-pkgs/vendored"));

Implementations

Source

impl Project

pub fn new( manifest_path: impl Into<PathBuf>, lock_path: impl Into<PathBuf>, pkg_dir: impl Into<PkgDir>, ) -> Self

Fully explicit constructor.

pub fn in_dir(root: impl AsRef<Path>, pkg_dir: impl Into<PkgDir>) -> Self

Conventional filenames under root, with an explicit PkgDir.

manifest = <root>/mlua-pkg.toml, lock = <root>/mlua-pkg.lock.

pub fn manifest_path(&self) -> &Path

Path to mlua-pkg.toml.

pub fn lock_path(&self) -> &Path

Path to mlua-pkg.lock.

pub fn pkg_dir(&self) -> &PkgDir

Base directory for cache + vendored output.

pub fn manifest_root(&self) -> PathBuf

Directory that contains the manifest.

Dep::target_dir values are resolved relative to this. A bare filename ("mlua-pkg.toml") yields ".".